@@ -25,7 +25,7 @@ use std::{
 /// As [`terminal_size::terminal_size()`] function doesn't return anything in docker containers
 /// (used for gitlab tests), we need to return a default value: `80`.
 fn get_terminal_width() -> usize {
-    #[cfg(runtime)]
+    #[cfg(not(any(test, feature = "integration")))]
     if let Some((terminal_size::Width(w), _)) = terminal_size::terminal_size() {
         return w as usize;
     }
@@ -710,7 +710,7 @@ impl KanOrgBoard {
         }
 
         // Avoid calling the text editor during the tests
-        #[cfg(runtime)]
+        #[cfg(not(any(test, feature = "integration")))]
         Self::edit_file_interactivelly(last_task_path)?;
 
         self.save_config()?;
